Interfaccia utente — SoL 3, manuale utente

### Navigazione

- indice
- successivo |
- precedente |
- Manuale d'uso »

# Interfaccia utente

Ho cercato di mantenere l’interazione con l’utente la più semplice possibile, focalizzata sulla tipica gestione di un torneo: dato un club, selezionato il campionato, si crea un nuovo torneo e poi

1. si inseriscono i partecipanti, selezionandoli tra i giocatori ed eventualmente organizzandoli in squadre

   Nota

   Quando il numero di partecipanti è dispari, SoL gestisce automaticamente la presenza di un giocatore fantasma, contro il quale si vince sempre per 25—0 a tavolino (per questo motivo, i cartellini di gioco relativi a queste fantomatiche partite non vengono neppure stampati). In casi particolari l’effettivo punteggio assegnato al giocatore può essere cambiato nella maschera di Inserimento e modifica.

2. eventualmente si stampano le Tessere personali iniziali

3. si crea il primo turno: se il torneo è associato a una particolare valutazione Glicko verrà generato utilizzando la valutazione corrente di ciascun giocatore, altrimenti in ordine casuale; in ogni caso il gestore del torneo può aggiustare a mano le combinazione generate dal computer

4. si stampano i Cartellini per il nuovo turno
5. si gioca!
6. si raccolgono i Cartellini compilati e si inseriscono i risultati
7. eventualmente si stampa la classifica aggiornata
8. si da ascolto ai pignoli che fanno notare qualche errore, si corregge e si ristampa
9. nel caso, si permette l’iscrizione di ulteriori giocatori o si consente il ritiro a chi lo richiede
10. si genera il prossimo turno e si ripete dal punto 4 in poi fino a piena soddisfazione, oppure finché sono possibili ulteriori combinazioni
11. si assegnano i premi finali, si stampa la classifica e le Tessere finali

- Autenticazione
- Anagrafiche di base
  - Filtri
  - Inserimento, cancellazione e modifica
  - Gestione giocatori
  - Gestione club
  - Gestione campionati
  - Gestione tornei
  - Gestione valutazioni Glicko
  - Valutazioni dei giocatori
- Altre finestre
  - Orologio
  - Caricamento

### Navigazione

- indice
- successivo |
- precedente |
- Manuale d'uso »